@@ -1,6 +1,4 @@
-var get = require('lodash.get');
-
-exports.getLocation = function(message) {
+exports.getLocation = function (message) {
   var messageNode = message.node;
 
   var location = {
@@ -8,11 +6,12 @@ exports.getLocation = function(message) {
     column: message.column,
   };
 
-  var messageInput = get(messageNode, 'source.input');
+  var messageInput = messageNode && messageNode.source && messageNode.source.input;
 
   if (!messageInput) return location;
 
-  var originLocation = messageInput.origin && messageInput.origin(message.line, message.column);
+  var originLocation =
+    messageInput.origin && messageInput.origin(message.line, message.column);
   if (originLocation) return originLocation;
 
   location.file = messageInput.file || messageInput.id;
